# Song Lyrics analysis

This repository contains files for analysis of song lyrics using a database of song lyrics from [Genius](genius.com). This project is a part of my master thesis. For further description you can read [thesis' text](https://github.com/plakato/Master-thesis).
